.. _bibliography:
.. index:: Bibliography

Bibliography
***************

.. [Gao2019]
   | Zirui Gao, Manuel Guizar-Sicairos, Viviane Lutz-Bueno, Aileen Schröter, Marianne Liebi, Markus Rudin and Marios Georgiadis
   | *High-speed tensor tomography: iterative reconstruction tensor tomography (IRTT) algorithm*
   | Acta Crystallographica Section A **75**, 223 (2019)
   | DOI: `10.1107/S2053273318017394  <https://doi.org/10.1107/S2053273318017394>`_

.. [Liebi2018]
   | Marianne Liebi, Marios Georgiadis, Joachim Kohlbrecher, Mirko Holler, J{\"{o}}rg Raabe, Ivan Usov, Andreas Menzel, Philipp Schneider, Oliver Bunk and Manuel Guizar-Sicairos
   | *Small-angle X-ray scattering tensor tomography: model of the three-dimensional reciprocal-space map, reconstruction algorithm and angular sampling requirements*
   | Acta Crystallographica Section A **74**, 12 (2018)
   | DOI: `10.1107/S205327331701614X  <https://doi.org/10.1107/S205327331701614X>`_

.. [Liebi2015]
   | Marianne Liebi, Marios Georgiadis, Andreas Menzel, Philipp  Schneider, Joachim  Kohlbrecher, Oliver Bunk, and Manuel Guizar-Sicairos
   | *Nanostructure surveys of macroscopic specimens by small-angle scattering tensor tomography*
   | Nature **527**, 349 (2015)
   | DOI: `10.1038/nature16056  <https://doi.org/10.1038/nature16056>`_

.. [Nielsen2023]
   | Leonard C. Nielsen, Paul Erhart, Manuel Guizar-Sicairos and Marianne Liebi
   | *Small-angle scattering tensor tomography algorithm for robust reconstruction of complex textures*
   | arXiv:2305.07750
   | DOI: `10.48550/arXiv.2305.07750 <https://doi.org/10.48550/arXiv.2305.07750>`_

.. [Schaff2015]
   | Florian Schaff, Martin Bech, Paul Zaslansky, Christoph Jud, Marianne Liebi, Manuel Guizar-Sicairos, and Franz Pfeiffer
   | *Six-dimensional real and reciprocal space small-angle X-ray scattering tomography*
   | Nature **527**, 353 (2015)
   | DOI: `10.1038/nature16060 <https://doi.org/10.1038/nature16060>`_
